@@ -4,7 +4,7 @@
 import sys
 import os
 import traceback
-from typing import Any, Optional, TYPE_CHECKING
+from typing import TYPE_CHECKING
 from pathlib import Path
 
 from pmb.helpers.exceptions import BuildFailedError, NonBugError
@@ -15,7 +15,7 @@ if TYPE_CHECKING:
 from . import config
 from . import parse
 from .config import init as config_init, require_programs
-from .helpers import frontend
+from .helpers import frontend as frontend
 from .helpers import logging
 from .helpers import mount
 from .helpers import other
@@ -25,7 +25,7 @@ from .core.context import get_context
 from .commands import run_command
 
 # pmbootstrap version
-__version__ = "3.2.0"
+__version__ = "3.3.1"
 
 # Python version check
 # === CHECKLIST FOR UPGRADING THE REQUIRED PYTHON VERSION ===
